@@ -2,6 +2,7 @@
 #define ALARMWINDOW_H
 
 #include <QWidget>
+#include <QTimer>
 
 namespace Ui {
     class AlarmWindow;
@@ -19,6 +20,7 @@ public slots:
     void showSettingsDialog();
     void homeScreenChanged(bool isOnCurrentHomescreen);
     void listClicked();
+    void fillAlarmList();
 
 protected:
     void mouseReleaseEvent ( QMouseEvent * e );
@@ -26,7 +28,6 @@ protected:
 private:
     void loadSettings();
     void showClock();
-    void fillAlarmList();
     void updateUi();
 
 private:
@@ -36,6 +37,15 @@ private:
     QFont m_font;
     QColor m_color;
     bool m_showCaption;
+    bool m_showTitle;
+    bool m_showRemain;
+    bool m_showRecurrent;
+    bool m_showIfEmpty;
+//    bool m_showStdOnly;
+    int m_alarmFilter;
+    int m_timeFrame;
+
+    QTimer *m_timer;
 };
 
 #endif // ALARMWINDOW_H
