@@ -9,12 +9,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="alarmwindow.cpp" line="61"/>
+        <location filename="alarmwindow.cpp" line="65"/>
         <source>alarms in next %1 h</source>
         <translation type="unfinished">будильники (на %1 ч)</translation>
     </message>
     <message>
-        <location filename="alarmwindow.cpp" line="192"/>
+        <location filename="alarmwindow.cpp" line="161"/>
+        <source>d</source>
+        <translation type="unfinished">д</translation>
+    </message>	
+    <message>
+        <location filename="alarmwindow.cpp" line="219"/>
         <source>--:--</source>
         <translation type="unfinished"></translation>
     </message>	
@@ -63,13 +68,13 @@
     </message>
     <message>
         <location filename="settingsdialog.ui" line="154"/>
-        <source>Будильники + Календарь</source>
-        <translation type="unfinished"></translation>
+        <source>Alarms + Calendar</source>
+        <translation type="unfinished">Будильники + Календарь</translation>
     </message>
     <message>
         <location filename="settingsdialog.ui" line="159"/>
-        <source>Все события</source>
-        <translation type="unfinished"></translation>
+        <source>All Events</source>
+        <translation type="unfinished">Все события</translation>
     </message>
     <message>
         <location filename="settingsdialog.ui" line="167"/>
@@ -92,17 +97,17 @@
         <translation type="unfinished">Диапазон (ч)</translation>
     </message>    
     <message>
-        <location filename="settingsdialog.ui" line="187"/>
+        <location filename="settingsdialog.ui" line="251"/>
         <source>Time Remain</source>
         <translation type="unfinished">Оставшееся время</translation>
     </message>    
     <message>
-        <location filename="settingsdialog.ui" line="194"/>
+        <location filename="settingsdialog.ui" line="270"/>
         <source>Header</source>
         <translation type="unfinished">Заголовок</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="201"/>
+        <location filename="settingsdialog.ui" line="282"/>
         <source>Title</source>
         <translation type="unfinished">Название</translation>
     </message>
